WebSkyCIB — so_pysm_models v0.4.dev210

so_pysm_models:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- so_pysm_models v0.4.dev210 »
- WebSkyCIB

# WebSkyCIB

class `so_pysm_models.` `WebSkyCIB`(websky_version='0.3', input_units='MJysr', target_nside=4096, interpolation_kind='linear', pixel_indices=None, mpi_comm=None, verbose=False)

  Bases: `so_pysm_models.InterpolatingComponent`

  PySM component interpolating between precomputed maps

  Methods Summary

  `get_filenames`(path) | Get filenames for a websky version For a standard interpolating component, we list files in folder, here we need to know the names in advance so that we can only download the required maps
  `read_map`(freq) |

  Methods Documentation

  `get_filenames`(path)

    Get filenames for a websky version For a standard interpolating component, we list files in folder, here we need to know the names in advance so that we can only download the required maps

  `read_map`(freq)